==> deposits_oneclick_checkout-0.0.2.tar.gz: lib/app/model/get_funding_source/get_funding_response.dart <==
// To parse this JSON data, do
//
//     final getFundingResponse = getFundingResponseFromJson(jsonString);

import 'dart:convert';

GetFundingResponse getFundingResponseFromJson(String str) => GetFundingResponse.fromJson(json.decode(str));

String getFundingResponseToJson(GetFundingResponse data) => json.encode(data.toJson());

class GetFundingResponse {
    GetFundingResponse({
        this.status,
        this.message,
        this.data,
    });

    String? status;
    String? message;
    Data? data;

    factory GetFundingResponse.fromJson(Map<String, dynamic> json) => GetFundingResponse(
        status: json["status"] == null ? null : json["status"],
        message: json["message"] == null ? null : json["message"],
        data: json["data"] == null ||json["data"] == '' ? null : Data.fromJson(json["data"]),
    );

    Map<String, dynamic> toJson() => {
        "status": status == null ? null : status,
        "message": message == null ? null : message,
        "data": data == null ? null : data!.toJson(),
    };
}

class Data {
    Data({
        this.cards,
        this.bankAccounts,
    });

    List<Card>? cards;
    List<BankAccount>? bankAccounts;

    factory Data.fromJson(Map<String, dynamic> json) => Data(
        cards: json["cards"] == null ? null : List<Card>.from(json["cards"].map((x) => Card.fromJson(x))),
        bankAccounts: json["bank_accounts"] == null ? null : List<BankAccount>.from(json["bank_accounts"].map((x) => BankAccount.fromJson(x))),
    );

    Map<String, dynamic> toJson() => {
        "cards": cards == null ? null : List<dynamic>.from(cards!.map((x) => x.toJson())),
        "bank_accounts": bankAccounts == null ? null : List<dynamic>.from(bankAccounts!.map((x) => x.toJson())),
    };
}

class BankAccount {
    BankAccount({
        this.id,
        this.type,
        this.bank,
        this.accountName,
        this.accountType,
        this.accountNumber,
        this.routingNumber,
        this.accountLimit,
        this.status,
        this.accountOwnerName,
        this.accountOwnerEmail,
        this.accountOwnerPhone,
        this.createdAt,
    });

    int? id;
    dynamic type;
    String? bank;
    String? accountName;
    String? accountType;
    String? accountNumber;
    String? routingNumber;
    dynamic accountLimit;
    String? status;
    String? accountOwnerName;
    String? accountOwnerEmail;
    String? accountOwnerPhone;
    DateTime? createdAt;

    factory BankAccount.fromJson(Map<String, dynamic> json) => BankAccount(
        id: json["id"] == null ? null : json["id"],
        type: json["type"],
        bank: json["bank"] == null ? null : json["bank"],
        accountName: json["account_name"] == null ? null : json["account_name"],
        accountType: json["account_type"] == null ? null : json["account_type"],
        accountNumber: json["account_number"] == null ? null : json["account_number"],
        routingNumber: json["routing_number"] == null ? null : json["routing_number"],
        accountLimit: json["account_limit"],
        status: json["status"] == null ? null : json["status"],
        accountOwnerName: json["account_owner_name"] == null ? null : json["account_owner_name"],
        accountOwnerEmail: json["account_owner_email"] == null ? null : json["account_owner_email"],
        accountOwnerPhone: json["account_owner_phone"] == null ? null : json["account_owner_phone"],
        createdAt: json["created_at"] == null ? null : DateTime.parse(json["created_at"]),
    );

    Map<String, dynamic> toJson() => {
        "id": id == null ? null : id,
        "type": type,
        "bank": bank == null ? null : bank,
        "account_name": accountName == null ? null : accountName,
        "account_type": accountType == null ? null : accountType,
        "account_number": accountNumber == null ? null : accountNumber,
        "routing_number": routingNumber == null ? null : routingNumber,
        "account_limit": accountLimit,
        "status": status == null ? null : status,
        "account_owner_name": accountOwnerName == null ? null : accountOwnerName,
        "account_owner_email": accountOwnerEmail == null ? null : accountOwnerEmail,
        "account_owner_phone": accountOwnerPhone == null ? null : accountOwnerPhone,
        "created_at": createdAt == null ? null : createdAt!.toIso8601String(),
    };
}

class Card {
    Card({
        this.id,
        this.authCode,
        this.primaryCard,
        this.status,
        this.cardOwnerName,
        this.cardOwnerEmail,
        this.cardOwnerPhone,
        this.metaDataJson,
        this.createdAt,
    });

    int? id;
    String? authCode;
    String? primaryCard;
    String? status;
    String? cardOwnerName;
    String? cardOwnerEmail;
    String? cardOwnerPhone;
    MetaDataJson? metaDataJson;
    DateTime? createdAt;

    factory Card.fromJson(Map<String, dynamic> json) => Card(
        id: json["id"] == null ? null : json["id"],
        authCode: json["auth_code"] == null ? null : json["auth_code"],
        primaryCard: json["primary_card"] == null ? null : json["primary_card"],
        status: json["status"] == null ? null : json["status"],
        cardOwnerName: json["card_owner_name"] == null ? null : json["card_owner_name"],
        cardOwnerEmail: json["card_owner_email"] == null ? null : json["card_owner_email"],
        cardOwnerPhone: json["card_owner_phone"] == null ? null : json["card_owner_phone"],
        metaDataJson: json["meta_data_json"] == null ? null : MetaDataJson.fromJson(json["meta_data_json"]),
        createdAt: json["created_at"] == null ? null : DateTime.parse(json["created_at"]),
    );

    Map<String, dynamic> toJson() => {
        "id": id == null ? null : id,
        "auth_code": authCode == null ? null : authCode,
        "primary_card": primaryCard == null ? null : primaryCard,
        "status": status == null ? null : status,
        "card_owner_name": cardOwnerName == null ? null : cardOwnerName,
        "card_owner_email": cardOwnerEmail == null ? null : cardOwnerEmail,
        "card_owner_phone": cardOwnerPhone == null ? null : cardOwnerPhone,
        "meta_data_json": metaDataJson == null ? null : metaDataJson!.toJson(),
        "created_at": createdAt == null ? null : createdAt!.toIso8601String(),
    };
}

class MetaDataJson {
    MetaDataJson({
        this.status,
        this.responseCode,
        this.responseMessage,
        this.token,
        this.expirationDate,
        this.cardType,
        this.maskedCardNumber,
        this.cardTransactionIdentifier,
        this.taskId,
        this.transactionId,
        this.transactionTimestamp,
        this.expiration,
        this.cvv,
        this.fullName,
        this.issuer,
    });

    String? status;
    String? responseCode;
    String? responseMessage;
    String? token;
    String? expirationDate;
    String? cardType;
    String? maskedCardNumber;
    String? cardTransactionIdentifier;
    String? taskId;
    String? transactionId;
    DateTime? transactionTimestamp;
    String? expiration;
    String? cvv;
    String? fullName;
    List<Issuer>? issuer;

    factory MetaDataJson.fromJson(Map<String, dynamic> json) => MetaDataJson(
        status: json["status"] == null ? null : json["status"],
        responseCode: json["responseCode"] == null ? null : json["responseCode"],
        responseMessage: json["responseMessage"] == null ? null : json["responseMessage"],
        token: json["token"] == null ? null : json["token"],
        expirationDate: json["expirationDate"] == null ? null : json["expirationDate"],
        cardType: json["cardType"] == null ? null : json["cardType"],
        maskedCardNumber: json["maskedCardNumber"] == null ? null : json["maskedCardNumber"],
        cardTransactionIdentifier: json["cardTransactionIdentifier"] == null ? null : json["cardTransactionIdentifier"],
        taskId: json["taskID"] == null ? null : json["taskID"],
        transactionId: json["transactionID"] == null ? null : json["transactionID"],
        transactionTimestamp: json["transactionTimestamp"] == null ? null : DateTime.parse(json["transactionTimestamp"]),
        expiration: json["expiration"] == null ? null : json["expiration"],
        cvv: json["cvv"] == null ? null : json["cvv"],
        fullName: json["full_name"] == null ? null : json["full_name"],
        issuer: json["issuer"] == null ? null : List<Issuer>.from(json["issuer"].map((x) => Issuer.fromJson(x))),
    );

    Map<String, dynamic> toJson() => {
        "status": status == null ? null : status,
        "responseCode": responseCode == null ? null : responseCode,
        "responseMessage": responseMessage == null ? null : responseMessage,
        "token": token == null ? null : token,
        "expirationDate": expirationDate == null ? null : expirationDate,
        "cardType": cardType == null ? null : cardType,
        "maskedCardNumber": maskedCardNumber == null ? null : maskedCardNumber,
        "cardTransactionIdentifier": cardTransactionIdentifier == null ? null : cardTransactionIdentifier,
        "taskID": taskId == null ? null : taskId,
        "transactionID": transactionId == null ? null : transactionId,
        "transactionTimestamp": transactionTimestamp == null ? null : transactionTimestamp!.toIso8601String(),
        "expiration": expiration == null ? null : expiration,
        "cvv": cvv == null ? null : cvv,
        "full_name": fullName == null ? null : fullName,
        "issuer": issuer == null ? null : List<dynamic>.from(issuer!.map((x) => x.toJson())),
    };
}

class Issuer {
    Issuer({
        this.cardNumber,
        this.brand,
        this.cardType,
        this.bankName,
        this.country,
    });

    String? cardNumber;
    String? brand;
    String? cardType;
    String? bankName;
    String? country;

    factory Issuer.fromJson(Map<String, dynamic> json) => Issuer(
        cardNumber: json["Card_Number"] == null ? null : json["Card_Number"],
        brand: json["Brand"] == null ? null : json["Brand"],
        cardType: json["Card_Type"] == null ? null : json["Card_Type"],
        bankName: json["Bank_Name"] == null ? null : json["Bank_Name"],
        country: json["Country"] == null ? null : json["Country"],
    );

    Map<String, dynamic> toJson() => {
        "Card_Number": cardNumber == null ? null : cardNumber,
        "Brand": brand == null ? null : brand,
        "Card_Type": cardType == null ? null : cardType,
        "Bank_Name": bankName == null ? null : bankName,
        "Country": country == null ? null : country,
    };
}

==> deposits_oneclick_checkout-0.0.3.tar.gz: lib/app/model/get_funding_source/get_funding_response.dart <==
// To parse this JSON data, do
//
//     final getFundingResponse = getFundingResponseFromJson(jsonString);

import 'package:deposits_oneclick_checkout/app/common/utils/exports.dart';

GetFundingResponse getFundingResponseFromJson(String str) => GetFundingResponse.fromJson(json.decode(str));

String getFundingResponseToJson(GetFundingResponse data) => json.encode(data.toJson());

class GetFundingResponse {
    GetFundingResponse({
        this.status,
        this.message,
        this.data,
    });

    String? status;
    String? message;
    GetFundingData? data;

    factory GetFundingResponse.fromJson(Map<String, dynamic> json) => GetFundingResponse(
        status: json["status"] == null ? null : json["status"],
        message: json["message"] == null ? null : json["message"],
        data: json["data"] == null ||json["data"] == '' ? null : GetFundingData.fromJson(json["data"]),
    );

    Map<String, dynamic> toJson() => {
        "status": status == null ? null : status,
        "message": message == null ? null : message,
        "data": data == null ? null : data!.toJson(),
    };
}

class GetFundingData {
    GetFundingData({
        this.cards,
        this.bankAccounts,
    });

    List<Cards>? cards;
    List<BankAccount>? bankAccounts;

    factory GetFundingData.fromJson(Map<String, dynamic> json) => GetFundingData(
        cards: json["cards"] == null ? null : List<Cards>.from(json["cards"].map((x) => Cards.fromJson(x))),
        bankAccounts: json["bank_accounts"] == null ? null : List<BankAccount>.from(json["bank_accounts"].map((x) => BankAccount.fromJson(x))),
    );

    Map<String, dynamic> toJson() => {
        "cards": cards == null ? null : List<dynamic>.from(cards!.map((x) => x.toJson())),
        "bank_accounts": bankAccounts == null ? null : List<dynamic>.from(bankAccounts!.map((x) => x.toJson())),
    };
}
